"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStyle = exports.getContainer = exports.getHtml = exports.getNav = exports.getPackageOpf = void 0;
const tslib_1 = require("tslib");
const dayjs_1 = (0, tslib_1.__importDefault)(require("dayjs"));
const getPackageOpf = (book) => {
    const manifestItems = book.catalogs
        .map((cpt, index) => {
        const arr = cpt.split('/');
        const fileName = arr[arr.length - 1].replace('.htm', '.xhtml');
        return `<item id="chapter${index}"  href="xhtml/${fileName}" media-type="application/xhtml+xml"/>`;
    })
        .join('\n');
    const spineItems = book.catalogs
        .map((_, index) => `<itemref idref="chapter${index}" />`)
        .join('\n');
    return `<?xml version="1.0" encoding="UTF-8"?>
<package xmlns="http://www.idpf.org/2007/opf" version="3.0" xml:lang="en" unique-identifier="q">
<metadata xmlns:dc="http://purl.org/dc/elements/1.1/">
  <dc:title id="title">${book.name}</dc:title>
  <dc:language>zh-Hans</dc:language>
  <dc:identifier id="q">99dl-zsakvo</dc:identifier>
  <dc:creator>${book.author}</dc:creator>
  <meta property="dcterms:modified">${(0, dayjs_1.default)(new Date()).format('YYYY-MM-DDThh:mm:ss') + 'Z'}</meta>
</metadata>
<manifest>
  <item id="cover" properties="cover-image" href="image/cover.jpg" media-type="image/jpeg"/>
  ${manifestItems}
  <item id="nav"  href="nav.xhtml" media-type="application/xhtml+xml" properties="nav"/>
  <item id="style"  href="css/style.css" media-type="text/css"/>
</manifest>
<spine>
  <itemref idref="nav" />
  ${spineItems}
</spine>
</package>
  `;
};
exports.getPackageOpf = getPackageOpf;
const getContainer = () => {
    return `<?xml version="1.0" encoding="UTF-8" ?>
<container version="1.0" xmlns="urn:oasis:names:tc:opendocument:xmlns:container">
    <rootfiles>
      <rootfile full-path="OPS/package.opf" media-type="application/oebps-package+xml"/>
    </rootfiles>
</container>
  `;
};
exports.getContainer = getContainer;
const getNav = (book) => {
    const lis = book.catalogs
        .map((cpt, index) => {
        const arr = cpt.split('/');
        const fileName = arr[arr.length - 1].replace('.htm', '.xhtml');
        return `<li><a href="xhtml/${fileName}">${book.chapters[index]}</a></li>`;
    })
        .join('\n');
    return `<html
  xmlns="http://www.w3.org/1999/xhtml"
  xmlns:epub="http://www.idpf.org/2007/ops"
  xml:lang="en"
>
  <head>
    <title>目录</title>
    <link rel="stylesheet" href="css/style.css" />
  </head>
  <body>
    <p class="empty-block-1"><br /></p>
    <p class="title">目录</p>
    <p class="empty-block-1"><br /></p>
    <nav epub:type="toc">
      <ol>
        ${lis}
      </ol>
    </nav>
  </body>
</html>
  `;
};
exports.getNav = getNav;
const getHtml = (title, paragraphs) => {
    const bodyContent = paragraphs.map((p) => `<p>${p}</p>`).join('\n');
    return `<html
  xmlns="http://www.w3.org/1999/xhtml"
  xmlns:epub="http://www.idpf.org/2007/ops"
  xml:lang="zh-Hans"
>
  <head>
    <title>${title}</title>
    <link rel="stylesheet" href="../css/style.css" />
  </head>
  <body>
    <p class="empty-block-1"><br /></p>
    <p class="title">${title}</p>
    <p class="empty-block-1"><br /></p>
    ${bodyContent}  
  </body>
</html>
`;
};
exports.getHtml = getHtml;
const getStyle = () => {
    return `.woff2 {
font-family: "Open Sans";
}

.remote {
font-family: Charmonman;
}

.empty-block-1{
  margin: 1em 0;
}

.title{
  margin: 1em 0 1.25em 0;
  font-size: 1.125em;
  font-weight: bold;
}

a {
  text-decoration: underline;
  color: inherit;
}

li {
  list-style: none;
  margin: 8px 0;
}

ol {
  padding-inline-start: 0px;
}
  `;
};
exports.getStyle = getStyle;
